summaryrefslogtreecommitdiffstats
path: root/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/wizards/newaccountwizard/knewaccountwizard.h')
-rw-r--r--kmymoney2/wizards/newaccountwizard/knewaccountwizard.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h b/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h
index c8a149c..69e8aa7 100644
--- a/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h
+++ b/kmymoney2/wizards/newaccountwizard/knewaccountwizard.h
@@ -21,7 +21,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-class QString;
+class TQString;
// ----------------------------------------------------------------------------
// Project Includes
@@ -67,8 +67,9 @@ class Wizard : public KMyMoneyWizard
friend class AccountSummaryPage;
Q_OBJECT
+ TQ_OBJECT
public:
- Wizard(QWidget* parent = 0, const char* name = 0, bool modal = false, WFlags flags = 0);
+ Wizard(TQWidget* tqparent = 0, const char* name = 0, bool modal = false, WFlags flags = 0);
/**
* Returns the information about the account as entered by
@@ -82,12 +83,12 @@ public:
void setAccount(const MyMoneyAccount& acc);
/**
* Returns the information about the parent account as entered by
* the user.
* @note For now it's either fixed as Asset or Liability. We will provide
* user selected parent accounts later.
*/
- const MyMoneyAccount& parentAccount(void);
+ const MyMoneyAccount& tqparentAccount(void);
/**
* Returns information about the schedule. If the returned value
@@ -82,12 +83,12 @@ public:
void setAccount(const MyMoneyAccount& acc);
/**
- * Returns the information about the parent account as entered by
+ * Returns the information about the tqparent account as entered by
* the user.
* @note For now it's either fixed as Asset or Liability. We will provide
@@ -82,12 +83,12 @@ public:
* the user.
* @note For now it's either fixed as Asset or Liability. We will provide
- * user selected parent accounts later.
+ * user selected tqparent accounts later.
*/